@@ -1,12 +1,12 @@
 package checks
 
 import (
+	"fmt"
 	"os"
 	"sort"
 	"strings"
 	"text/template"
 
-	"github.com/pkg/errors"
 	"github.com/spf13/cobra"
 	"golang.stackrox.io/kube-linter/internal/defaultchecks"
 	"golang.stackrox.io/kube-linter/internal/flagutil"
@@ -44,7 +44,7 @@ KubeLinter includes the following built-in checks:
 
 **Remediation**: {{.Remediation}}
 
-**Template**: [{{.Template}}](generated/templates.md#{{ templateLink . }})
+**Template**: [{{.Template}}](templates.md#{{ templateLink . }})
 {{ if .Params }}
 **Parameters**:
 
@@ -114,7 +114,7 @@ func Command() *cobra.Command {
 func GetTemplateLink(check *config.Check) (string, error) {
 	t, found := templates.Get(check.Template)
 	if !found {
-		return "", errors.Errorf("unexpected: check %v references non-existent template?", check)
+		return "", fmt.Errorf("unexpected: check %v references non-existent template?", check)
 	}
 	return strings.Join(strings.Fields(strings.ToLower(t.HumanName)), "-"), nil
 }
