@@ -3,6 +3,7 @@ package lintcontext
 import (
 	"bufio"
 	"bytes"
+	"context"
 	"errors"
 	"fmt"
 	"io"
@@ -12,6 +13,9 @@ import (
 	"strings"
 
 	"github.com/bmatcuk/doublestar/v4"
+	manifestengine "github.com/lburgazzoli/k8s-manifests-lib/pkg/engine"
+	"github.com/lburgazzoli/k8s-manifests-lib/pkg/renderer/kustomize"
+	"github.com/lburgazzoli/k8s-manifests-lib/pkg/types"
 	ocsAppsV1 "github.com/openshift/api/apps/v1"
 	ocpSecV1 "github.com/openshift/api/security/v1"
 	k8sMonitoring "github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring/v1"
@@ -21,11 +25,13 @@ import (
 	"helm.sh/helm/v3/pkg/chart/loader"
 	"helm.sh/helm/v3/pkg/chartutil"
 	"helm.sh/helm/v3/pkg/cli/values"
-	"helm.sh/helm/v3/pkg/engine"
+	helmEngine "helm.sh/helm/v3/pkg/engine"
 	autoscalingV2Beta1 "k8s.io/api/autoscaling/v2beta1"
 	v1 "k8s.io/api/core/v1"
+	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/serializer"
+	runtimeYaml "k8s.io/apimachinery/pkg/runtime/serializer/yaml"
 	"k8s.io/apimachinery/pkg/util/yaml"
 	"k8s.io/client-go/kubernetes/scheme"
 	y "sigs.k8s.io/yaml"
@@ -58,7 +64,17 @@ func parseObjects(data []byte, d runtime.Decoder) ([]k8sutil.Object, error) {
 	}
 	obj, _, err := d.Decode(data, nil, nil)
 	if err != nil {
-		return nil, fmt.Errorf("failed to decode: %w", err)
+		// this is for backward compatibility, should be replaced with kubeconform
+		if strings.Contains(err.Error(), "json: cannot unmarshal") {
+			return nil, fmt.Errorf("failed to decode: %w", err)
+		}
+		// fallback to unstructured as schema validation will be performed by kubeconform check
+		dec := runtimeYaml.NewDecodingSerializer(unstructured.UnstructuredJSONScheme)
+		var unstructuredErr error
+		obj, _, unstructuredErr = dec.Decode(data, nil, obj)
+		if unstructuredErr != nil {
+			return nil, fmt.Errorf("failed to decode: %w: %w", err, unstructuredErr)
+		}
 	}
 	if list, ok := obj.(*v1.List); ok {
 		objs := make([]k8sutil.Object, 0, len(list.Items))
@@ -115,7 +131,7 @@ func (l *lintContextImpl) renderValues(chrt *chart.Chart, values map[string]inte
 		return nil, err
 	}
 
-	e := engine.Engine{LintMode: true}
+	e := helmEngine.Engine{LintMode: true}
 	rendered, err := e.Render(chrt, valuesToRender)
 	if err != nil {
 		return nil, fmt.Errorf("failed to render: %w", err)
@@ -310,3 +326,59 @@ func normalizeDirectoryPaths(renderedFiles map[string]string) map[string]string
 	}
 	return normalizedFiles
 }
+
+func (l *lintContextImpl) loadObjectsFromKustomize(dir string) {
+	// Create a kustomize engine with source annotations enabled
+	kustomizeSource := kustomize.Source{Path: dir}
+	ignoreWarnings := func(warnings []string) error {
+		// Ignore warnings, similar to how we suppress Helm logs with nopWriter
+		return nil
+	}
+	e, err := manifestengine.Kustomize(
+		kustomizeSource,
+		kustomize.WithSourceAnnotations(true),
+		kustomize.WithWarningHandler(ignoreWarnings),
+	)
+	if err != nil {
+		l.addInvalidObjects(InvalidObject{Metadata: ObjectMetadata{FilePath: dir}, LoadErr: err})
+		return
+	}
+
+	// Render the kustomize manifests
+	ctx := context.Background()
+	objects, err := e.Render(ctx)
+	if err != nil {
+		l.addInvalidObjects(InvalidObject{Metadata: ObjectMetadata{FilePath: dir}, LoadErr: err})
+		return
+	}
+
+	// Convert each object to YAML and load it
+	for _, obj := range objects {
+		// Marshal the underlying object content to YAML
+		yamlData, err := y.Marshal(obj.UnstructuredContent())
+		if err != nil {
+			loadErr := fmt.Errorf("marshaling kustomize object %s/%s from %s: %w", obj.GetKind(), obj.GetName(), dir, err)
+			l.addInvalidObjects(InvalidObject{Metadata: ObjectMetadata{FilePath: dir}, LoadErr: loadErr})
+			continue
+		}
+
+		// Extract the source file from annotations if available
+		filePath := ""
+		if annotations := obj.GetAnnotations(); annotations != nil {
+			if sourceFile, ok := annotations[types.AnnotationSourceFile]; ok && sourceFile != "" {
+				// Prefix with the kustomization directory to show full path
+				filePath = filepath.Join(dir, sourceFile)
+			}
+		}
+		// Fallback: Create a file path for the object for reporting purposes
+		if filePath == "" {
+			filePath = filepath.Join(dir, fmt.Sprintf("%s-%s.yaml", strings.ToLower(obj.GetKind()), obj.GetName()))
+		}
+
+		// Load the object using the existing YAML reader
+		if err := l.loadObjectsFromReader(filePath, bytes.NewReader(yamlData)); err != nil {
+			loadErr := fmt.Errorf("loading object %s from rendered kustomization %s: %w", filePath, dir, err)
+			l.addInvalidObjects(InvalidObject{Metadata: ObjectMetadata{FilePath: filePath}, LoadErr: loadErr})
+		}
+	}
+}
