@@ -19,6 +19,7 @@ import (
 	_ "golang.stackrox.io/kube-linter/pkg/templates/dnsconfigoptions"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/duplicatenvvar"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/envvar"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/envvarvaluefrom"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/forbiddenannotation"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/hostipc"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/hostmounts"
@@ -27,6 +28,7 @@ import (
 	_ "golang.stackrox.io/kube-linter/pkg/templates/hpareplicas"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/imagepullpolicy"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/jobttlsecondsafterfinished"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/kubeconform"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/latesttag"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/livenessport"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/livenessprobe"
@@ -56,6 +58,7 @@ import (
 	_ "golang.stackrox.io/kube-linter/pkg/templates/sccdenypriv"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/serviceaccount"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/servicetype"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/sortedkeys"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/startupport"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/sysctl"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/targetport"
