@@ -9,5 +9,5 @@ package toolimports
 
 import (
 	_ "github.com/golangci/golangci-lint/v2/cmd/golangci-lint"
-	_ "github.com/goreleaser/goreleaser"
+	_ "github.com/goreleaser/goreleaser/v2"
 )
